@@ -4,7 +4,7 @@ use std::{collections::HashMap, fs::File, io::LineWriter};
 use serde::{Serialize, Deserialize};
 
 /// Mako Vocab Object
-#[derive(Serialize, Deserialize, Default)]
+#[derive(Serialize, Deserialize, Default, Clone)]
 pub struct Vocab {
     pub num_tokens: u32,
     pub token2index: HashMap<String, u32>,
@@ -112,6 +112,12 @@ impl Vocab {
     }
 }
 
+impl lentrait::Len for Vocab {
+    fn len(&self) -> usize {
+        self.len()
+    }
+}
+
 /// Load the BPE vocab from an internal vocab file into a Vocab object
 pub fn load_bpe_vocab() -> Vocab {
     use serde_json::{Value};
